/*************************************************************************//**
 *
 * @file hw_mpu6050.h
 * @brief Hardware layer Definition of Cox based I2C Driver
 * for Invensense MPU-6050
 *
 * @version 1.1
 * @date 03/13/2013
 * @author Amo Xu  amo@amoxu.com
 * @copyright Copyright (c)  2012, Amo Xu   All rights reserved.
 *
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * * Neither the name of the <ORGANIZATION> nor the names of its
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/


#ifndef __HW_MPU_6050_H
#define __HW_MPU_6050_H
#include "hard_com.h"
/**
 * If building with a C++ compiler, make all of the definitions in this header
 * have a C binding.
 */
#ifdef __cplusplus
extern "C"
{
#endif

/**
 * @addtogroup HW_DEF Hardware Register Macros
 * @brief Address of hardware registers
 * @{
 */

/**
 * @brief Address of Sample Rate Configuration
 */
#define SMPLRT_DIV      0x19

/**
 * @brief Address of Sensor Configuration
 */
#define CONFIG          0x1A

/**
 * @brief Address of Gyroscope Configuration
 */
#define GYRO_CONFIG     0x1B

/**
 * @brief Address of Accelerometer Configuration
 */
#define ACCEL_CONFIG    0x1C

/**
 * @brief Address of High bit Accelerometer X axis output
 */
#define ACCEL_XOUT_H    0x3B

/**
 * @brief Address of Low bit Accelerometer X axis output
 */
#define ACCEL_XOUT_L    0x3C

/**
 * @brief Address of High bit Accelerometer Y axis output
 */
#define ACCEL_YOUT_H    0x3D

/**
 * @brief Address of Low bit Accelerometer Y axis output
 */
#define ACCEL_YOUT_L    0x3E

/**
 * @brief Address of High bit Accelerometer Z axis output
 */
#define ACCEL_ZOUT_H    0x3F

/**
 * @brief Address of Low bit Accelerometer Z axis output
 */
#define ACCEL_ZOUT_L    0x40

/**
 * @brief Address of High bit Temperature output
 */
#define TEMP_OUT_H      0x41

/**
 * @brief Address of Low bit Temperature output
 */
#define TEMP_OUT_L      0x42

/**
 * @brief Address of High bit Gyroscope X axis output
 */
#define GYRO_XOUT_H     0x43

/**
 * @brief Address of Low bit Gyroscope X axis output
 */
#define GYRO_XOUT_L     0x44

/**
 * @brief Address of High bit Gyroscope Y axis output
 */
#define GYRO_YOUT_H     0x45

/**
 * @brief Address of Low bit Gyroscope Y axis output
 */
#define GYRO_YOUT_L     0x46

/**
 * @brief Address of High bit Gyroscope Z axis output
 */
#define GYRO_ZOUT_H     0x47

/**
 * @brief Address of Low bit Gyroscope Z axis output
 */
#define GYRO_ZOUT_L     0x48

/**
 * @brief Address of Power Configuration
 */
#define PWR_MGMT_1      0x6B

/**
 * @brief Address of Identity of the device(readonly)
 */
#define WHO_AM_I        0x75
/**
 * @}
 */


#ifdef __cplusplus
}
#endif

#endif
//! end of __HW_MPU_6050_H

